@@ -112,13 +112,13 @@ public class AllFoldersConnector extends BaseConnector<FoldersResponseMto> {
         return builder.build();
     }
 
-    public static List<Folder> map(Object[][] data, String archiveFolderId, boolean includeNonPrivateFolders, int userId) {
+    public static List<Folder> map(Object[][] data, String archiveFolderId, boolean includeNonPrivateFolders) {
         if (data == null) {
             return Collections.emptyList();
         }
         List<Folder> folders = new ArrayList<>();
         for (Object[] folderData : data) {
-            Folder folder = map(folderData, userId);
+            Folder folder = AllFoldersConnector.map(folderData);
             if (folder != null && isMailFolder(folder, includeNonPrivateFolders)) {
                 if (folder.getId().equals(archiveFolderId)) {
                     folder = folder.withType(Folder.Type.ARCHIVE);
@@ -129,14 +129,14 @@ public class AllFoldersConnector extends BaseConnector<FoldersResponseMto> {
         return folders;
     }
 
-    public static Folder map(Object[] data, int userId) {
+    public static Folder map(Object[] data) {
         String folderId = (String) data[0];
         String parentFolderId = (String) data[1];
         String name = (String) data[2];
         Integer folderType = (Integer) data[3];
         Integer standardFolderType = (Integer) data[4];
         Folder.Type type = lookupType(standardFolderType, folderType);
-        boolean isUserVisible = isUserVisible(data[5], userId);
+        boolean isUserVisible = isUserVisible(data[5]);
         return isUserVisible ? new Folder(folderId, parentFolderId, name, type) : null;
     }
 
@@ -192,18 +192,16 @@ public class AllFoldersConnector extends BaseConnector<FoldersResponseMto> {
         return isSubFolder && (includeNonPrivateFolders || (!Folder.Type.PUBLIC.equals(folder.getType()) && !Folder.Type.SHARED.equals(folder.getType())));
     }
 
-    private static boolean isUserVisible(Object data, int userId) {
+    private static boolean isUserVisible(Object data) {
         if (data instanceof List) {
             List<?> permissionList = (List<?>) data;
-            if (permissionList.size() == 1) {
-                Object obj = permissionList.get(0);
+            for (Object obj : permissionList) {
                 if (obj instanceof Map) {
                     @SuppressWarnings("unchecked")
                     Map<String, Object> permissions = (Map<String, Object>) obj;
-                    Object entity = permissions.get("entity");
                     Object bits = permissions.get("bits");
-                    if (entity instanceof Integer && bits instanceof Integer) {
-                        return ((Integer) entity).intValue() == userId && ((Integer) bits).intValue() > 64;
+                    if (bits instanceof Integer) {
+                        return ((Integer) bits).intValue() > 64;
                     }
                 }
             }
