@@ -59,7 +59,6 @@ import javax.ws.rs.core.MediaType;
 import javax.ws.rs.core.Response;
 
 import com.openexchange.mobile.api.facade.configuration.ConfigurationHelper;
-import com.openexchange.mobile.api.facade.configuration.HostConfiguration;
 import com.openexchange.mobile.api.facade.endpoints.responses.ctos.ManifestCto;
 import com.openexchange.mobile.api.facade.models.Manifest;
 import com.openexchange.mobile.api.facade.services.ManifestService;
@@ -80,10 +79,7 @@ public class ManifestEndpoint {
     @Produces(MediaType.APPLICATION_JSON)
     public Response getManifest(@Context HttpServletRequest request) {
         log.info("Retrieving manifest");
-        String userAgent = RequestUtil.getUserAgent(request);
-        String hostname = RequestUtil.getHostHeader(request);
-        HostConfiguration configuration = ConfigurationHelper.getConfiguration(hostname);
-        RequestUtil.checkUserAgent(userAgent, configuration);
+        ConfigurationHelper.getConfiguration(request);
         Manifest manifest = manifestService.getManifest();
         ManifestCto manifestCto = new ManifestCto(manifest);
         return RequestUtil.jsonResponse(manifestCto);
